import { app } from '@/app.ts';
import { User } from '@/models/user.ts';
import { Org } from '@/models/org.ts';
// 获取组织的用户列表
app
  .route({
    path: 'org-user',
    key: 'list',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const tokenUser = ctx.state.tokenUser;
    const { orgId } = ctx.query;
    const org = await Org.findByPk(orgId);
    if (!org) {
      ctx.throw('组织不存在');
    }
    // const users = await user.getUsers();
    ctx.body = org;
  })
  .addTo(app);

app
  .route({
    path: 'org-user',
    key: 'operate',
    middleware: ['check-auth-admin'],
  })
  .define(async (ctx) => {
    const tokenAdmin = ctx.state.tokenAdmin;
    const tokenUser = ctx.state.tokenUser;
    const data = ctx.query.data;
    const { orgId, userId, username, action, role } = data;
    const org = await Org.findByPk(orgId);
    if (!org) {
      ctx.throw('组织不存在');
    }
    let user: User;
    if (userId) {
      user = await User.findByPk(userId);
    } else if (username) {
      user = await User.findOne({ where: { username } });
    }
    if (!user) {
      ctx.throw('用户不存在');
    }
    if (user.type !== 'user') {
      ctx.throw('用户类型错误');
    }
    const operateId = tokenUser.uid || tokenUser.id;
    if (action === 'add') {
      await org.addUser(user, { needPermission: true, role: role || 'user', operateId, isAdmin: !!tokenAdmin });
    } else if (action === 'remove') {
      await org.removeUser(user, { needPermission: true, operateId, isAdmin: !!tokenAdmin });
    } else {
      ctx.throw('操作错误');
    }
    ctx.body = 'ok';
  })
  .addTo(app);
